from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("subscriptionmanager", "0005_consolidatedprofitandlossmonth"),
    ]

    operations = [
        migrations.AlterField(
            model_name="consolidatedprofitandlossmonth",
            name="reporting_fx_rate",
            field=models.DecimalField(
                decimal_places=4, default=Decimal("0.0000"), max_digits=12
            ),
        ),
    ]




import os

# We need to be able to swap a model from being managed/unmanaged if it is being imported or not
DATAWAREHOUSE_MANAGED_MODELS = bool(os.environ.get("DATAWAREHOUSE_MANAGED_MODELS", False))



# Generated by Django 3.2.16 on 2024-01-17 00:12

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0011_synceddata'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='synceddata',
            name='data',
        ),
        migrations.AddField(
            model_name='synceddata',
            name='oauth_state',
            field=models.JSONField(decoder=django.core.serializers.json.DjangoJSONEncoder, default=list, encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-09 14:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0003_auto_20230123_0443'),
    ]

    operations = [
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='downgrades_book',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='downgrades_contract',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='loss_value',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='new_paying_value',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='total_contract_paying_value',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='upgrades_book',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='revenueforecastsummary',
            name='upgrades_contract',
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2023-06-06 06:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0004_customreportsummary'),
    ]

    operations = [
        migrations.AddField(
            model_name='constancesetting',
            name='last_synced',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='extensionsummary',
            name='last_synced',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='featureflagsummary',
            name='last_synced',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='templatechangerequestsummary',
            name='last_synced',
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-17 00:58

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0013_rename_oauth_state_synceddata_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='synceddata',
            name='data',
            field=models.JSONField(default=list, encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-10 19:14

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0008_remove_constancesetting_last_reported'),
    ]

    operations = [
        migrations.CreateModel(
            name='TemplateStatSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField(db_index=True)),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('object_pk', models.IntegerField()),
                ('object_content_type_name', models.CharField(max_length=100)),
                ('created', models.DateTimeField()),
                ('region', models.CharField(max_length=10)),
                ('name', models.CharField(max_length=250)),
                ('key', models.CharField(max_length=250)),
                ('extends', models.CharField(blank=True, default='', max_length=250)),
                ('usage_total', models.IntegerField()),
                ('usage_this_year', models.IntegerField()),
                ('usage_last_year', models.IntegerField()),
                ('libraries_loaded', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=250), blank=True, default=list, size=None)),
                ('deprecated_functions', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=250), blank=True, default=list, size=None)),
                ('is_active', models.BooleanField()),
            ],
            options={
                'db_table': 'workforce"."template_stat_summary',
                'managed': True,
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-01-21 02:47

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('workforce', '0001_schema'),
    ]

    operations = [
        migrations.CreateModel(
            name='ConstanceSetting',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=100)),
                ('setting_name', models.TextField()),
                ('setting_value', models.TextField(null=True)),
                ('last_reported', models.DateTimeField()),
            ],
            options={
                'db_table': 'workforce"."constance_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='ExtensionSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('name', models.CharField(max_length=100)),
                ('is_enabled', models.BooleanField(db_index=True)),
            ],
            options={
                'db_table': 'workforce"."extension_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='FeatureFlagSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('name', models.CharField(max_length=100)),
                ('is_enabled', models.BooleanField(db_index=True)),
            ],
            options={
                'db_table': 'workforce"."featureflag_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='OnboardingActionRow',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('last_synced', models.DateTimeField(db_index=True)),
                ('is_active', models.BooleanField(db_index=True)),
                ('name', models.CharField(max_length=150)),
                ('description', models.TextField(blank=True, default='')),
                ('due_date', models.DateField(blank=True, null=True)),
                ('completed_date', models.DateField(blank=True, null=True)),
                ('responsibility', models.CharField(max_length=100)),
                ('assigned_to', models.CharField(blank=True, default='', max_length=100)),
                ('progress', models.IntegerField(blank=True, null=True)),
                ('effort', models.IntegerField(blank=True, null=True)),
                ('group', models.CharField(max_length=100)),
            ],
            options={
                'db_table': 'workforce"."customer_onboarding_actions',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='ServerUsage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(max_length=200)),
                ('staff_licenses_total', models.IntegerField()),
                ('staff_licenses_used', models.IntegerField()),
                ('staff_licenses_additional', models.IntegerField()),
                ('desk_licenses_used', models.IntegerField()),
                ('field_licenses_used', models.IntegerField()),
                ('contractor_licenses_used', models.IntegerField()),
                ('customer_licenses_used', models.IntegerField()),
                ('api_licenses_used', models.IntegerField()),
                ('reporting_licenses_used', models.IntegerField()),
                ('timesheet_licenses_used', models.IntegerField()),
                ('last_synced', models.DateTimeField()),
                ('for_date', models.DateField()),
            ],
            options={
                'db_table': 'workforce"."licensing_usage',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TemplateChangeRequestSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('tcr_pk', models.PositiveIntegerField()),
                ('created', models.DateTimeField()),
                ('currency', models.CharField(blank=True, max_length=3, null=True)),
                ('requested_changes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=100), blank=True, default=list, size=None, verbose_name='Requested modifications')),
                ('status', models.CharField(db_index=True, max_length=20)),
                ('status_changed_requested', models.DateTimeField(null=True)),
                ('status_changed_approved', models.DateTimeField(null=True)),
                ('status_changed_completed', models.DateTimeField(null=True)),
                ('template_key', models.CharField(max_length=200)),
                ('template_name', models.CharField(max_length=200)),
                ('template_content_type_model', models.CharField(max_length=200)),
                ('estimated_price', models.PositiveIntegerField()),
                ('estimated_hours', models.DecimalField(decimal_places=4, max_digits=11)),
            ],
            options={
                'db_table': 'workforce"."templates_template_change_request_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='UsageMetrics',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('count_name', models.CharField(db_index=True, max_length=200)),
                ('stat_count', models.BigIntegerField()),
                ('as_of', models.DateTimeField(db_index=True)),
            ],
            options={
                'db_table': 'workforce"."usage_metrics',
                'managed': True,
            },
        ),
        migrations.CreateModel(
            name='UserSummaryRow',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField(db_index=True)),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('user_pk', models.PositiveIntegerField(db_index=True)),
                ('email', models.CharField(db_index=True, max_length=255)),
                ('name', models.CharField(max_length=255)),
                ('license', models.CharField(db_index=True, max_length=10)),
                ('is_active', models.BooleanField(db_index=True)),
                ('is_superuser', models.BooleanField(db_index=True)),
                ('created', models.DateTimeField(db_index=True)),
                ('last_access', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('groups', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=150), blank=True, default=list, size=None)),
            ],
            options={
                'db_table': 'workforce"."customer_all_users',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='WorkforceAddressSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('last_synced', models.DateTimeField(null=True)),
                ('prop_status', models.CharField(blank=True, max_length=30)),
                ('prop_id', models.IntegerField()),
                ('prop_created', models.DateTimeField(null=True)),
                ('address', models.CharField(blank=True, help_text='Exact and validated registered postal address.', max_length=1000)),
                ('display', models.TextField(help_text='Address that will be used for display purposes.', max_length=1000)),
                ('country', models.CharField(blank=True, choices=[('AU', 'Australia'), ('NZ', 'New Zealand')], default='AU', max_length=2)),
                ('gnaf_id', models.CharField(blank=True, default='', max_length=30)),
                ('state', models.CharField(blank=True, default='', max_length=50, verbose_name='State or Region')),
                ('postal_code', models.CharField(blank=True, default='', max_length=15, verbose_name='Postal or Zip code')),
                ('coords', models.CharField(blank=True, max_length=40)),
            ],
            options={
                'db_table': 'workforce"."address_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AddIndex(
            model_name='usagemetrics',
            index=models.Index(fields=['tenant', 'count_name', '-as_of'], name='usage_metrics_latest_btree'),
        ),
        migrations.AlterUniqueTogether(
            name='serverusage',
            unique_together={('tenant', 'for_date')},
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-05 10:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0007_auto_20230704_2306'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='constancesetting',
            name='last_reported',
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-26 14:39

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0009_templatestatsummary'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(db_index=True, default=datetime.date.today),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-06-23 21:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0009_subscriptionsummary_billing_entity_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_by_guid',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_contract_value',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_guid',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_upgrade_or_downgrade_amount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2023-07-04 15:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0005_auto_20230606_0658'),
    ]

    operations = [
        migrations.AddField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-16 23:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0010_alter_usagemetrics_for_date'),
    ]

    operations = [
        migrations.CreateModel(
            name='SyncedData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('key', models.CharField(db_index=True, max_length=200)),
                ('data', models.JSONField()),
                ('last_synced', models.DateTimeField(db_index=True, null=True)),
            ],
            options={
                'db_table': 'workforce"."synced_data',
                'managed': True,
                'default_permissions': (),
                'unique_together': {('tenant', 'key')},
            },
        ),
    ]



# Generated by Django 3.2.16 on 2024-05-16 02:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0006_alter_reporting_fx_rate_2024_04_15'),
    ]

    operations = [
        migrations.CreateModel(
            name='AddonSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('category', models.CharField(blank=True, max_length=100)),
                ('equivalent', models.CharField(blank=True, max_length=100)),
                ('metered_value', models.CharField(max_length=50)),
                ('price_aud', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_nzd', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_gbp', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_cad', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_usd', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('is_current', models.BooleanField(default=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_addon_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='PlanSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('category', models.CharField(blank=True, max_length=100)),
                ('equivalent', models.CharField(blank=True, max_length=100)),
                ('included_users', models.IntegerField()),
                ('price_aud', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_nzd', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_gbp', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_cad', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('price_usd', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('recommended_addon_name', models.CharField(blank=True, max_length=100)),
                ('is_current', models.BooleanField(default=True)),
                ('expects_licensing_usage', models.BooleanField(default=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_plan_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='termination_notification_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-17 00:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0012_auto_20240117_0012'),
    ]

    operations = [
        migrations.RenameField(
            model_name='synceddata',
            old_name='oauth_state',
            new_name='data',
        ),
    ]



# Generated by Django 3.2.16 on 2023-02-05 23:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='serverusage',
            name='contractor_addons_used',
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 4.1.5 on 2023-01-12 00:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = []

    operations = [
        migrations.RunSQL("""
        create schema if not exists vitally
        """),
    ]


# Generated by Django 3.2.16 on 2023-01-21 02:47

from decimal import Decimal
import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('subscriptionmanager', '0001_schema'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChangeSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('subscription_guid', models.UUIDField()),
                ('customer_name', models.CharField(max_length=200)),
                ('customer_account_number', models.CharField(max_length=50)),
                ('currency', models.CharField(max_length=3)),
                ('change_type', models.TextField(null=True)),
                ('date', models.DateField()),
                ('note', models.TextField(blank=True)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=10)),
                ('salesperson', models.CharField(max_length=200)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_change_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='ChargeSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField(null=True)),
                ('created', models.DateTimeField(null=True)),
                ('updated', models.DateTimeField(null=True)),
                ('requestor', models.CharField(max_length=200)),
                ('subscription_guid', models.UUIDField()),
                ('customer_name', models.CharField(max_length=200)),
                ('customer_account_number', models.CharField(max_length=50)),
                ('currency', models.CharField(max_length=3)),
                ('itemcode', models.CharField(max_length=20)),
                ('description', models.CharField(max_length=500)),
                ('account_code', models.CharField(max_length=20)),
                ('quantity', models.DecimalField(decimal_places=2, max_digits=10)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=10)),
                ('tracking_category_1', models.CharField(max_length=50)),
                ('tracking_category_2', models.CharField(max_length=50)),
                ('subtotal', models.DecimalField(decimal_places=2, max_digits=10)),
                ('total', models.DecimalField(decimal_places=2, max_digits=10)),
                ('invoice_date', models.DateField(null=True)),
                ('invoice_reference', models.CharField(max_length=20, null=True)),
                ('invoice_number', models.CharField(max_length=20, null=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_charge_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='PaymentMethodSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('customer_account_number', models.CharField(max_length=50)),
                ('gocardless_id', models.CharField(max_length=100)),
                ('stripe_id', models.CharField(max_length=100)),
                ('description', models.CharField(blank=True, max_length=250)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_paymentmethod_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='RecurringCreditSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('subscription_guid', models.UUIDField()),
                ('customer_name', models.CharField(max_length=200)),
                ('customer_account_number', models.CharField(max_length=50)),
                ('currency', models.CharField(max_length=3)),
                ('start_date', models.DateField()),
                ('review_date', models.DateField(blank=True, null=True)),
                ('expiry_date', models.DateField()),
                ('amount', models.DecimalField(decimal_places=2, max_digits=10)),
                ('invoice_text', models.CharField(max_length=200)),
                ('internal_note', models.CharField(blank=True, max_length=500)),
                ('credit_classification', models.TextField()),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_recurring_credit_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='RevenueForecastSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('month', models.DateField()),
                ('total_contract_value', models.DecimalField(decimal_places=2, max_digits=10)),
                ('total_credit_value', models.DecimalField(decimal_places=2, max_digits=10)),
                ('signed_value', models.DecimalField(decimal_places=2, max_digits=10)),
                ('starting_value', models.DecimalField(decimal_places=2, max_digits=10)),
                ('subs_total', models.IntegerField()),
                ('subs_total_paying', models.IntegerField()),
                ('subs_starting', models.IntegerField()),
                ('subs_won', models.IntegerField()),
                ('subs_lost', models.IntegerField()),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_revenueforecast_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='SubscriptionSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('created', models.DateTimeField()),
                ('updated', models.DateTimeField()),
                ('salesperson', models.CharField(max_length=200)),
                ('product', models.CharField(max_length=200, null=True)),
                ('customer_name', models.CharField(max_length=200)),
                ('customer_account_number', models.CharField(db_index=True, max_length=50)),
                ('customer_xero_guid', models.UUIDField(blank=True, null=True)),
                ('customer_primary_contact_name', models.CharField(max_length=200)),
                ('customer_primary_contact_email', models.CharField(max_length=200)),
                ('customer_accounts_contact_name', models.CharField(max_length=200)),
                ('customer_accounts_contact_email', models.CharField(max_length=200)),
                ('customer_company_tax_number', models.CharField(help_text='ABN, NZBN or VAT number.', max_length=50)),
                ('subscription_guid', models.UUIDField()),
                ('currency', models.CharField(max_length=3)),
                ('signing_date', models.DateField()),
                ('billing_date', models.DateField()),
                ('plan', models.CharField(max_length=100)),
                ('staff_addon_name', models.CharField(max_length=100)),
                ('plan_included_licenses', models.IntegerField(blank=True, null=True)),
                ('additional_committed_staff', models.IntegerField(blank=True, null=True)),
                ('total_contracted_staff_licenses', models.IntegerField(blank=True, null=True)),
                ('override_plan_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('override_staff_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('effective_discount', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('total_contract_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('hosting_addon_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('bi_addon_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('sla_addon_price', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('workspaces', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=50), blank=True, default=list, size=None)),
                ('termination_date', models.DateField(blank=True, null=True)),
                ('termination_code', models.TextField(blank=True)),
                ('termination_reason', models.TextField(blank=True)),
                ('current_expansion_chargeable', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('current_total_mrr_chargeable', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('current_total_used_staff_licenses', models.IntegerField(blank=True, null=True)),
                ('current_total_additional_chargable_licenses', models.IntegerField(blank=True, null=True)),
                ('current_monthly_recurring_credit', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('lastmonth_expansion_charged', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('lastmonth_total_mrr_charged', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('lastmonth_total_used_staff_licenses', models.IntegerField(blank=True, null=True)),
                ('lastmonth_total_used_desk_licenses', models.IntegerField(blank=True, null=True)),
                ('lastmonth_total_used_field_licenses', models.IntegerField(blank=True, null=True)),
                ('lastmonth_total_additional_chargable_licenses', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_subscription_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='WorkspaceSummary',
            fields=[
                ('last_synced', models.DateTimeField()),
                ('guid', models.UUIDField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=50)),
                ('customer_account_number', models.CharField(max_length=50)),
                ('subscription_guid', models.UUIDField()),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_workspace_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='XeroContactSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('customer_name', models.CharField(max_length=200, null=True)),
                ('customer_account_number', models.CharField(max_length=50, null=True)),
                ('customer_first_name', models.CharField(max_length=100, null=True)),
                ('customer_last_name', models.CharField(max_length=100, null=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_xero_customer_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='XeroInvoiceSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('invoice_guid', models.UUIDField()),
                ('contact_guid', models.UUIDField()),
                ('contact_name', models.CharField(max_length=200)),
                ('contact_account_number', models.CharField(max_length=50)),
                ('number', models.CharField(max_length=50)),
                ('reference', models.CharField(max_length=100)),
                ('date', models.DateField(blank=True, null=True)),
                ('due_date', models.DateField(blank=True, null=True)),
                ('subtotal', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('total', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('status', models.CharField(max_length=50)),
                ('currency', models.CharField(max_length=3)),
                ('currency_rate', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('is_sent', models.BooleanField(default=False)),
                ('repeating_invoice_guid', models.UUIDField(null=True)),
                ('amount_due', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('amount_paid', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('fully_paid_on_date', models.DateField(blank=True, null=True)),
            ],
            options={
                'db_table': 'subscriptionmanager"."billing_xero_invoice_summary',
                'managed': True,
                'default_permissions': (),
            },
        ),
    ]



# Generated by Django 3.2.16 on 2024-06-23 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0008_auto_20240531_1445'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='billing_entity_name',
            field=models.CharField(default='', max_length=250),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-07-11 00:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0010_auto_20240623_2142'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='deal_originator',
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2023-07-04 23:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0006_usagemetrics_for_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='serverusage',
            name='for_date',
            field=models.DateField(db_index=True),
        ),
        migrations.AlterField(
            model_name='serverusage',
            name='tenant',
            field=models.CharField(db_index=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(db_index=True, null=True),
        ),
        migrations.AddIndex(
            model_name='usagemetrics',
            index=models.Index(fields=['tenant', 'count_name', '-for_date'], name='usage_metrics_date_btree'),
        ),
    ]



# Generated by Django 3.2.16 on 2024-05-31 14:45

from decimal import Decimal
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0007_auto_20240516_0257'),
    ]

    operations = [
        migrations.CreateModel(
            name='NetPaidMRRValue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('entity_name', models.CharField(max_length=200)),
                ('customer_account_code', models.CharField(max_length=200)),
                ('date', models.DateField()),
                ('local_account_code', models.CharField(max_length=100)),
                ('local_account_name', models.CharField(max_length=300)),
                ('subtotal', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('currency', models.CharField(max_length=3)),
            ],
            options={
                'db_table': 'subscriptionmanager"."net_paid_mrr_value',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AddField(
            model_name='addonsummary',
            name='last_synced',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='plansummary',
            name='last_synced',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
